package com.napa.pulse.refactor.controller;

import com.google.gson.Gson;
import com.napa.pulse.annotations.JwtToken;
import com.napa.pulse.dto.SKUTableWidgetData;

import com.napa.pulse.entity.security.User;
import com.napa.pulse.refactor.exception.UserNotAuthorizedException;
import com.napa.pulse.security.model.JwtUserData;
import com.napa.pulse.service.interfaces.ReviewService;
import com.napa.pulse.service.interfaces.UserService;
import com.napa.pulse.utils.PulseConstants;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;

@RestController
@RequestMapping("/auth/v2")
public class RefactorReviewRestController {
    private static final Logger LOGGER = LoggerFactory.getLogger(RefactorReviewRestController.class);
    private final Gson gson = new Gson();

    @Autowired
    private ReviewService reviewService;
    @Autowired
    private UserService userService;

    @GetMapping("/sku-table-widget-data")
    public ResponseEntity<?> skuTableWidgetRestService(@RequestBody @JwtToken(PulseConstants.JWT_USER_DETAILS) JwtUserData jwtUserData,
                                                       SKUTableWidgetData skuTableWidgetData) {
        ResponseEntity<String> response = new ResponseEntity<>("", HttpStatus.OK);
        User user = userService.findUserByLogin(jwtUserData.getUsername());
        if(user==null){
            throw new UserNotAuthorizedException("user not found");
        }
        List<Map<String, Object>> skuData = reviewService.getSKUTableData(skuTableWidgetData, user);
        response = new ResponseEntity<>(gson.toJson(skuData), HttpStatus.OK);
        return response;

    }

}
